[Libreoffice-commits] core.git: sw/source

Julien Nabet serval2412 at yahoo.fr
Sun Jan 4 06:26:00 PST 2015


 sw/source/core/layout/calcmove.cxx |   12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

New commits:
commit 4eed16d83cad3446e250c23f9e9ca48a1d9a6d9c
Author: Julien Nabet <serval2412 at yahoo.fr>
Date:   Tue Feb 3 15:24:50 2015 +0100

    Typo: consequetive->consecutive
    
    Change-Id: I2c4c856a1f208c253493b852108743c643c2ea6d

diff --git a/sw/source/core/layout/calcmove.cxx b/sw/source/core/layout/calcmove.cxx
index d7bb1d3..5ece547 100644
--- a/sw/source/core/layout/calcmove.cxx
+++ b/sw/source/core/layout/calcmove.cxx
@@ -1048,7 +1048,7 @@ void SwCntntFrm::MakeAll()
     LockJoin();
     long nFormatCount = 0;
     // - loop prevention
-    int nConsequetiveFormatsWithoutChange = 0;
+    int nConsecutiveFormatsWithoutChange = 0;
     PROTOCOL_ENTER( this, PROT_MAKEALL, 0, 0 )
 
 #ifdef DBG_UTIL
@@ -1326,9 +1326,9 @@ void SwCntntFrm::MakeAll()
             if( nFormatCount > STOP_FLY_FORMAT )
                 SetFlyLock( true );
             // - loop prevention
             // No format any longer, if <cnStopFormat> consequetive formats
             // without change occur.
-            if ( nConsequetiveFormatsWithoutChange <= cnStopFormat )
+            if ( nConsecutiveFormatsWithoutChange <= cnStopFormat )
             {
                 Format();
             }
@@ -1445,11 +1445,11 @@ void SwCntntFrm::MakeAll()
             if ( aOldFrm_StopFormat == Frm() &&
                  aOldPrt_StopFormat == Prt() )
             {
-                ++nConsequetiveFormatsWithoutChange;
+                ++nConsecutiveFormatsWithoutChange;
             }
             else
             {
-                nConsequetiveFormatsWithoutChange = 0;
+                nConsecutiveFormatsWithoutChange = 0;
             }
         }
 
@@ -1634,7 +1634,7 @@ void SwCntntFrm::MakeAll()
         if ( bMoveOrFit && GetUpper() == pOldUp )
         {
             // FME 2007-08-30 #i81146# new loop control
-            if ( nConsequetiveFormatsWithoutChange <= cnStopFormat )
+            if ( nConsecutiveFormatsWithoutChange <= cnStopFormat )
             {
                 Prepare( PREP_MUST_FIT, 0, false );
                 mbValidSize = false;
@@ -1326,9 +1326,9 @@ void SwCntntFrm::MakeAll()
                 SetFlyLock( true );
             // - loop prevention
-            // No format any longer, if <cnStopFormat> consequetive formats
+            // No format any longer, if <cnStopFormat> consecutive formats
             // without change occur.


More information about the Libreoffice-commits mailing list